Seavees Baja Stripe | Lucky Brand

30% OFF ALL DENIM + EXTRA 30% OFF SALE

Send to a Friend

# SEAVEES BAJA STRIPE

## Details

http://www.luckybrand.com/seavees-baja-stripe/846922083062.html
846922083062 Style YLS0030
1 Review
$88.00 $52.80 Sale
2 left!

## Promotions

Winter Survival Sale: 40-50% Off Everything
*PRICE SHOWN INCLUDES DISCOUNT

Online Exclusive

## Variations

- Select Size
  - 9
  - 9.5
  - 10
  - 10.5
  - 11
- Color:
- Qty

Please choose all product options to add this product to your wishlist.
Please choose all product options to proceed.
Your bag has reached the maximum amount available for this item.

## Product Actions

Add to cart options
Availability:

In Stock

Add To Wishlist
Looking for a little help? Give us a call at
1 (866) 975-5825

## Additional Information

- MADE IN THE USA

REVIEW SNAPSHOT®

by PowerReviews
LUCKYSEAVEES BAJA STRIPE
4.0

(based on 1 review)

Ratings Distribution

- 5 Stars

  (0)

- 4 Stars

  (1)

- 3 Stars

  (0)

- 2 Stars

  (0)

- 1 Stars

  (0)

Reviewed by 1 customer

Displaying review 1

6/30/2013
4.0

Fun for the summer !

By scrubs

from Rochester, NY

Pros

Cons

Best Uses

Comments about LUCKY SEAVEES BAJA STRIPE:

Fun colors for the summer but not the most comfortable shoes I've ever worn.

- Age:
- 25 to 34
- Height:
- 6'0" and taller

Displaying review 1

You're now registered to receive Lucky email updates!

Sign up for Lucky emails today
and receive exclusive offers and styles
updates direct to your inbox!
* required field
There was a problem submitting your email, please try again.
First Name *
Last Name *
Email *
Zip Code *
Yes! Send me updates on Lucky Kid.
Yes! Send me updates on Lucky Plus.

ALREADY A MEMBER? SIGN IN!

<< Back
Sign Up for Lucky
Email Updates to Enjoy
Exclusive Sale Access

Read our Privacy Policy for more details.

Already signed up? Just enter your registered email address to gain access.